@@ -1,16 +1,22 @@
+pub mod accum;
 pub mod async_fifo;
+//pub mod bidirectional_bus;
 pub mod cross_fifo;
+pub mod delay_line;
 pub mod dff;
 pub mod edge_detector;
 pub mod fifo_expander_n;
 pub mod fifo_logic;
 pub mod fifo_reducer;
 pub mod fifo_reducer_n;
+pub mod fifo_register;
+pub mod mac_fir;
 pub mod prelude;
 pub mod pulser;
 pub mod pwm;
 pub mod ram;
 pub mod rom;
+pub mod sdram;
 pub mod shot;
 pub mod spi_master;
 pub mod spi_slave;
@@ -18,7 +24,4 @@ pub mod strobe;
 pub mod sync_fifo;
 pub mod sync_rom;
 pub mod synchronizer;
-pub mod accum;
-pub mod mac_fir;
 pub mod tristate;
-pub mod bidirectional_bus;
