@@ -3,18 +3,27 @@ pub use crate::declare_expanding_fifo;
 pub use crate::declare_narrowing_fifo;
 pub use crate::declare_sync_fifo;
 pub use crate::widgets::async_fifo::AsynchronousFIFO;
+//pub use crate::widgets::bidirectional_bus::{
+//    BidiBusD, BidiBusM, BidiMaster, BidiSimulatedDevice, FifoBus, FifoBusIn,
+//};
 pub use crate::widgets::cross_fifo::CrossNarrowFIFO;
 pub use crate::widgets::cross_fifo::CrossWidenFIFO;
+pub use crate::widgets::delay_line::DelayLine;
 pub use crate::widgets::dff::DFF;
 pub use crate::widgets::edge_detector::EdgeDetector;
 pub use crate::widgets::fifo_expander_n::FIFOExpanderN;
 pub use crate::widgets::fifo_expander_n::WordOrder;
 pub use crate::widgets::fifo_reducer::FIFOReducer;
 pub use crate::widgets::fifo_reducer_n::FIFOReducerN;
+pub use crate::widgets::fifo_register::RegisterFIFO;
+pub use crate::widgets::mac_fir::MultiplyAccumulateSymmetricFiniteImpulseResponseFilter;
 pub use crate::widgets::pulser::Pulser;
 pub use crate::widgets::pwm::PulseWidthModulator;
 pub use crate::widgets::ram::RAM;
 pub use crate::widgets::rom::ROM;
+pub use crate::widgets::sdram::cmd::SDRAMCommand;
+pub use crate::widgets::sdram::fifo_controller::SDRAMFIFOController;
+pub use crate::widgets::sdram::timings::MemoryTimings;
 pub use crate::widgets::shot::Shot;
 pub use crate::widgets::spi_master::{SPIConfig, SPIMaster, SPIWires};
 pub use crate::widgets::spi_slave::SPISlave;
@@ -24,6 +33,4 @@ pub use crate::widgets::sync_rom::SyncROM;
 pub use crate::widgets::synchronizer::{
     BitSynchronizer, SyncReceiver, SyncSender, VectorSynchronizer,
 };
-pub use crate::widgets::mac_fir::MultiplyAccumulateSymmetricFiniteImpulseResponseFilter;
 pub use crate::widgets::tristate::TristateBuffer;
-pub use crate::widgets::bidirectional_bus::{BidiDevice, BidiBusD, BidiBusM, BidiMaster};
